@@ -1,4 +1,4 @@
-class convert_for_training(self):
+class convert_for_training:
   def convert_train(self,om,trainfunc,data,params,factor):
     nm = copy.deepcopy(om)
     mem = inspect.getmembers(nm, lambda a:not(inspect.isroutine(a)))
@@ -11,19 +11,6 @@ class convert_for_training(self):
     nm = trainfunc(nm,data,params)
     return nm
 
-  def train_func(self,model,data):
-  """
-  Train your model here!
-  e.g
-  lr = 1e-3
-  optimizer = optim.Adam(nm.parameters(), lr=lr)
-  criterion = nn.CrossEntropyLoss()
-  device = torch.device('cuda' if torch.cuda.is_available() else 'cpu')
-  model = nm.to(device)
-  
-  """
-  return model
-
 from torch.nn.parameter import Parameter
 class Gru2(nn.module):
 
@@ -189,4 +176,4 @@ class CustomLSTM2(nn.Module):
         hidden_seq = hidden_seq.transpose(0,1).contiguous() #(50,b,1024) -> (b,50,1024)
         #print(hidden_seq.shape)
         state = (torch.cat([i.reshape(1,b,HS) for i in hnew]),torch.cat([i.reshape(1,b,HS) for i in cnew]))#((h1_t,c1_t),(h2_t,c2_t))
-        return hidden_seq, state  
\ No newline at end of file
+        return hidden_seq, state  
